# astropandas

Tools to expand on pandas functionality for astronomical applications.

## Features

- directly read and write FITS table data, see `astropandas.read_fits` and `astropandas.to_fits`
- match based on sky coordinates, see `astropandas.match`
